package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcBudgetSettle;

/**
 * cmc预结算Service接口
 * 
 * @author cmc
 * @date 2024-03-22
 */
public interface ICmcBudgetSettleService 
{
    /**
     * 查询cmc预结算
     * 
     * @param budgetId cmc预算id
     * @return cmc预结算
     */
    public List<CmcBudgetSettle> selectCmcBudgetSettleByBudgetId(String budgetId);

    /**
     * 查询cmc预结算列表
     * 
     * @param cmcBudgetSettle cmc预结算
     * @return cmc预结算集合
     */
    public List<CmcBudgetSettle> selectCmcBudgetSettleList(CmcBudgetSettle cmcBudgetSettle);

    /**
     * 新增cmc预结算
     * 
     * @param cmcBudgetSettle cmc预结算
     * @return 结果
     */
    public int insertCmcBudgetSettle(CmcBudgetSettle cmcBudgetSettle);

    /**
     * 修改cmc预结算
     * 
     * @param cmcBudgetSettle cmc预结算
     * @return 结果
     */
    public int updateCmcBudgetSettle(CmcBudgetSettle cmcBudgetSettle);

    /**
     * 批量删除cmc预结算
     * 
     * @param budgetIds 需要删除的cmc预结算主键集合
     * @return 结果
     */
    public int deleteCmcBudgetSettleByBudgetIds(String[] budgetIds);

    /**
     * 删除cmc预结算信息
     * 
     * @param budgetId cmc预结算主键
     * @return 结果
     */
    public int deleteCmcBudgetSettleByBudgetId(String budgetId);
}
